@@ -7,6 +7,8 @@ from core_module_blob_host_app.views.views import BlobHostModule
 
 urlpatterns = [
     re_path(
-        r"module-blob-host", BlobHostModule.as_view(), name="core_module_blob_host_view"
+        r"module-blob-host",
+        BlobHostModule.as_view(),
+        name="core_module_blob_host_view",
     ),
 ]
